@@ -8,7 +8,7 @@ function(q, prob, lower.tail=TRUE, log.p = FALSE)
 
 
 
-	.Internal(pbinom(q, 1, prob, lower.tail, log.p))
+	pbinom(q,size=1,prob=prob,lower.tail=lower.tail,log.p=log.p)
 
 	
 
